@@ -1,16 +1,13 @@
 #if !defined(__GHCVERSION_H__)
 #define __GHCVERSION_H__
 
-#if !defined(__GLASGOW_HASKELL__)
-#define __GLASGOW_HASKELL__ 902
-#endif
-#if !defined(__GLASGOW_HASKELL_FULL_VERSION__)
-#define __GLASGOW_HASKELL_FULL_VERSION__ "9.2.1"
-#endif
+#define __GLASGOW_HASKELL__ 904
+#define __GLASGOW_HASKELL_FULL_VERSION__ "9.4.3"
 
-#define __GLASGOW_HASKELL_PATCHLEVEL1__ 1
+#define __GLASGOW_HASKELL_PATCHLEVEL1__ 3
+#define __GLASGOW_HASKELL_PATCHLEVEL2__ 0
 
-#define MIN_VERSION_GLASGOW_HASKELL(ma,mi,pl1,pl2) (\
+#define MIN_VERSION_GLASGOW_HASKELL(ma,mi,pl1,pl2) ( \
    ((ma)*100+(mi)) <  __GLASGOW_HASKELL__ || \
    ((ma)*100+(mi)) == __GLASGOW_HASKELL__    \
           && (pl1) <  __GLASGOW_HASKELL_PATCHLEVEL1__ || \
